@@ -19,7 +19,7 @@ impl Client {
     pub async fn from_node_directory<P: Into<PathBuf>>(node_directory: P) -> anyhow::Result<Self> {
         let dir = OsDirectory::new(node_directory);
         let node = LocalNode::from_directory(dir)?;
-        Ok(Self::new(node).await?)
+        Self::new(node).await
     }
 
     pub async fn new(local_node: LocalNode) -> anyhow::Result<Self> {
